==> qtjambi-remoteobjects-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiRemoteObjects/QRemoteObjectSettingsStore_shell.h <==
#ifndef QREMOTEOBJECTSETTINGSSTORE_SHELL_H
#define QREMOTEOBJECTSETTINGSSTORE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectsettingsstore.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectSettingsStore_shell : public QRemoteObjectSettingsStore, public QtJambiShellInterface
{
public:
    QRemoteObjectSettingsStore_shell(QObject* parent0 = nullptr);
    ~QRemoteObjectSettingsStore_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QList<QVariant> restoreProperties(const QString& repName0, const QByteArray& repSig1) override;
    void saveProperties(const QString& repName0, const QByteArray& repSig1, const QList<QVariant>& values2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectSettingsStore_access : public QRemoteObjectSettingsStore
{
    jobject __qt_restoreProperties_cref_QString_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1);
    void __qt_saveProperties_cref_QString_cref_QByteArray_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1, jobject values2);
};

#endif // QREMOTEOBJECTSETTINGSSTORE_SHELL_H

==> qtjambi-remoteobjects-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiRemoteObjects/QRemoteObjectSettingsStore_shell.h <==
#ifndef QREMOTEOBJECTSETTINGSSTORE_SHELL_H
#define QREMOTEOBJECTSETTINGSSTORE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectsettingsstore.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectSettingsStore_shell : public QRemoteObjectSettingsStore, public QtJambiShellInterface
{
public:
    QRemoteObjectSettingsStore_shell(QObject* parent0 = nullptr);
    ~QRemoteObjectSettingsStore_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QList<QVariant> restoreProperties(const QString& repName0, const QByteArray& repSig1) override;
    void saveProperties(const QString& repName0, const QByteArray& repSig1, const QList<QVariant>& values2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectSettingsStore_access : public QRemoteObjectSettingsStore
{
    jobject __qt_restoreProperties_cref_QString_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1);
    void __qt_saveProperties_cref_QString_cref_QByteArray_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1, jobject values2);
};

#endif // QREMOTEOBJECTSETTINGSSTORE_SHELL_H
